Satellite
=========

.. currentmodule:: cysgp4

.. autoclass:: Satellite
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Satellite.mjd
      ~Satellite.pydt

   .. rubric:: Methods Summary

   .. autosummary::

      ~Satellite.eci_pos
      ~Satellite.geo_pos
      ~Satellite.topo_pos

   .. rubric:: Attributes Documentation

   .. autoattribute:: mjd
   .. autoattribute:: pydt

   .. rubric:: Methods Documentation

   .. automethod:: eci_pos
   .. automethod:: geo_pos
   .. automethod:: topo_pos
